@@ -18,6 +18,8 @@ if sys.version_info >= (3, 8):
 else:
     from typing_extensions import Literal
 
+import sys
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -463,6 +465,8 @@ DBEngineVersionTypeDef = TypedDict(
         "SupportedEngineModes": List[str],
         "SupportedFeatureNames": List[str],
         "Status": str,
+        "SupportsParallelQuery": bool,
+        "SupportsGlobalDatabases": bool,
     },
     total=False,
 )
@@ -535,6 +539,7 @@ DBInstanceTypeDef = TypedDict(
         "ReadReplicaSourceDBInstanceIdentifier": str,
         "ReadReplicaDBInstanceIdentifiers": List[str],
         "ReadReplicaDBClusterIdentifiers": List[str],
+        "ReplicaMode": Literal["open-read-only", "mounted"],
         "LicenseModel": str,
         "Iops": int,
         "OptionGroupMemberships": List["OptionGroupMembershipTypeDef"],
@@ -1002,6 +1007,7 @@ OrderableDBInstanceOptionTypeDef = TypedDict(
         "SupportsStorageAutoscaling": bool,
         "SupportsKerberosAuthentication": bool,
         "OutpostCapable": bool,
+        "SupportsGlobalDatabases": bool,
     },
     total=False,
 )
